pub struct CanRx<'d> { /* private fields */ }Expand description
FDCAN Rx only Instance
Implementations
Sourceimpl<'d> CanRx<'d>
impl<'d> CanRx<'d>
Sourcepub async fn read(&mut self) -> Result<Envelope, BusError>
pub async fn read(&mut self) -> Result<Envelope, BusError>
Returns the next received message frame
Sourcepub fn blocking_read(&mut self) -> Result<Envelope, BusError>
pub fn blocking_read(&mut self) -> Result<Envelope, BusError>
Blocking read frame.
If no CAN frame is in the RX buffer, this will wait until there is one.
Sourcepub async fn read_fd(&mut self) -> Result<FdEnvelope, BusError>
pub async fn read_fd(&mut self) -> Result<FdEnvelope, BusError>
Returns the next received message frame
Sourcepub fn blocking_read_fd(&mut self) -> Result<FdEnvelope, BusError>
pub fn blocking_read_fd(&mut self) -> Result<FdEnvelope, BusError>
Blocking read FD frame.
If no CAN FD frame is in the RX buffer, this will wait until there is one.